#
# spec file for package apache-rex
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define macros_dir            %{_rpmconfigdir}/macros.d
%define macros_file           macros.apache-rex

Name:           apache-rex
Version:        20211102
Release:        1.7
Summary:        Script for Apache HTTPD Runnable Examples
License:        Apache-2.0
Group:          Documentation/Howto
URL:            https://github.com/pgajdos/apache-rex
Source0:        %{name}.tar.bz2
Source1:        apache-rex-rpmlintrc
Source2:        %{macros_file}
# simple script to generate the tarball from a commit id
Source1000:     generate_tarball.sh
Requires:       apache2-devel
Requires:       apache2-utils
Requires:       curl
Requires:       lsof
Requires:       openssl
Requires:       openssl-devel
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%description
Runnable examples for Apache HTTP server. Can be used starting
point for examples, testcases and other inspiration.

%prep
%setup -q -n %{name}

%build

%install
mkdir -p %{buildroot}%{_bindir}
cp run-rex %{buildroot}%{_bindir}
mkdir -p %{buildroot}%{_docdir}/%{name}
cp -r */ LICENSE README.md contents %{buildroot}%{_docdir}/%{name}
mkdir -p %{buildroot}%{macros_dir}
install -m 644 %{SOURCE2} %{buildroot}%{macros_dir}/%{macros_file}

%files
%defattr(-,root,root)
%{_bindir}/run-rex
%{macros_dir}/%{macros_file}
%{_docdir}/%{name}

%changelog
* Thu Dec 16 2021 David Anes <david.anes@suse.com>
- version update to 20211102
  * add mod_php-ssl
* Tue Jan 12 2021 pgajdos@suse.com
- require apache2-utils
* Fri Jan  8 2021 pgajdos@suse.com
- version update to 20210108
  * count php8 in
* Wed Nov 25 2020 pgajdos@suse.com
- version update to 20201125
  * curl changed --help behavior
* Tue Sep  1 2020 pgajdos@suse.com
- version update to 20200901
  * added mod_proxy_express-basic-gdbm
  * amended mod_proxy_express-basic to use sdbm, which should
    be always available
* Sun May  3 2020 Neal Gompa <ngompa13@gmail.com>
- Replace incorrect usage of %%_libexecdir/rpm with %%_rpmconfigdir
* Tue Apr  7 2020 pgajdos@suse.com
- version update to 20200407
  * added mod_ssl-SSLProxyEngine
* Fri Apr  3 2020 pgajdos@suse.com
- version update to 20200403
  * added mod_proxy_http2-basic
* Thu Apr  2 2020 pgajdos@suse.com
- version update to 20200402
  * minor fixes
* Fri Feb 28 2020 pgajdos@suse.com
- version update to 20200228
  * refactor mod_authn_dbd-mysql, create lib/mysql
  * new mod_php-mysql
* Mon Feb 10 2020 pgajdos@suse.com
- version update to 20200210
  * add debug-wku
* Wed Dec 18 2019 pgajdos@suse.com
- version update to 20191219
  * modify: mod_authn_dbd-pgsql: control ipc
  * new:    mod_authz_unixgroup
* Tue Dec  3 2019 pgajdos@suse.com
- version update to 20191203
  * add uwsgi support
  * new
    . mod_proxy_uwsgi-basic
    . mod_wsgi-basic
* Tue Oct 22 2019 pgajdos@suse.com
- version update to 20191022
  * add softshm support
  * new
    . mod_whatkilledus-basic
    . mod_diagnostics-basic
    . mod_ssl-pkcs11
  * expand
    . core-ErrorLogFormat-basic
    . mod_ssl-basic
    . core-KeepAlive-basic
    . mod_log_config-basic
    . mod_log_debug-basic
    . mod_dumpio-basic
    . mod_log_forensic-basic
    . mod_unique_id-basic
* Fri Sep  6 2019 Petr Gajdos <pgajdos@suse.com>
- version update to 20191006
  * mod_ssl-basic: show SSL protocol used by default
* Wed Sep  4 2019 pgajdos@suse.com
- version update to 20191005
  * extended core-ranges-basic
  * fix openssl_ocsp_responder_stop()
  * more generic ssl error checking
  * mysql_install_db --force required by older distros
* Fri Jun 28 2019 pgajdos@suse.com
- version update to 20190628
  * new example mod_authnz_external-basic
  * nex example mod_nss-basic
* Thu Jun 27 2019 pgajdos@suse.com
- version update to 20190627
  * new example mod_bw-basic
  * new example mod_auth_token-basic
  * new example mod_rivet-basic
* Wed Jun 26 2019 pgajdos@suse.com
- version update to 20190626
  * new example mod_authn_otp-basic
  * new example mod_gnutls-basic
* Tue Jun 25 2019 pgajdos@suse.com
- version update to 20190625
  * new example mod_fcgid-basic
* Mon Jun 24 2019 pgajdos@suse.com
- version update to 20190624
  * new example mod_bmx-basic
  * new rpm macro %%apache_rex_deps
* Mon Jun 10 2019 pgajdos@suse.com
- version update to 20190610
  * run-rex: slight reactorization
  * new: mod_auth_core-env
  * fixed mod_proxy_ftp-basic (seccomp_sandbox=NO)
* Wed May 29 2019 pgajdos@suse.com
- version update to 20190529
  * prepare for usage in module package checking
- modified sources
  %% macros.apache-rex
* Fri Feb  8 2019 Petr Gajdos <pgajdos@suse.com>
- add mod_proxy_fcgi-php-fpm-auth-RewriteRule
* Tue Feb  5 2019 Petr Gajdos <pgajdos@suse.com>
- add mod_proxy_fcgi-php-fpm-CGIPassAuth
* Tue Jan 22 2019 Petr Gajdos <pgajdos@suse.com>
- run-rex: dynamic is not valid crypto device
* Tue Nov 27 2018 Petr Gajdos <pgajdos@suse.com>
- added mod_php-basic
- modules can be given as a regular expression, e. g. 'mod_php[5,7]'
* Fri Nov  9 2018 Petr Gajdos <pgajdos@suse.com>
- do not run mod_ssl-verify-server-OCSPStapling when curl does
  not support --cert-status
* Fri Nov  2 2018 Petr Gajdos <pgajdos@suse.com>
- ssl refactoring
- amended:
  * mod_ssl-basic
  * mod_ssl-SSLCryptoDevice
  * mod_ssl-verify-client
- moved:
  * mod_ssl-CRL to mod_ssl-verify-client-CRL
- new:
  * mod_ssl-verify-client-OCSP
  * mod_ssl-verify-server-CRL
  * mod_ssl-verify-server-OCSP
  * mod_ssl-verify-server-OCSPStapling
* Thu Sep 13 2018 Petr Gajdos <pgajdos@suse.com>
- core-HttpProtocolOptions-basic: fix for sle11 (nc had not wait
  for response)
- mod_perl-basic: fix for sle11 (was hardcoded 2.4 access control)
* Thu Aug 30 2018 pgajdos@suse.com
- core-Satisfy-basic works also for 2.4
* Mon Aug 13 2018 pgajdos@suse.com
- mod_proxy_scgi: use perl SCGI instead of python SCGI, which
  is not ported to python3 so far
* Fri Jul 20 2018 pgajdos@suse.com
- core-ServerAlias-basic: use NameVirtualHost where appropriate
  (fixes the test on sle11)
* Mon Jun 11 2018 pgajdos@suse.com
- add mod_authn_dbd-mysql
- add mod_authn_dbd-pgsql
* Wed Dec 27 2017 pgajdos@suse.com
- mod_macro-basic: lbmethod_traffic requires more trafic, otherwise
  sometimes (e. g. on i586 obs worker) it happend that backend1
  get backend1 all the requests
* Fri Dec 22 2017 pgajdos@suse.com
- add mod_ssl-verify-client
- add mod_ssl-CRL
* Thu Dec 21 2017 pgajdos@suse.com
- skip mod_ssl-basic when curl does not know --resolve
* Wed Nov 15 2017 pgajdos@suse.com
- updated to 20171117: flat directory structure under
  $AREX_RUN_DIR
- added macros.apache-rex
* Wed Oct  4 2017 pgajdos@suse.com
- move running %%check to apache-rex-check package
* Tue Sep 12 2017 pgajdos@suse.com
- amended mod_http-* to not run with prefork
* Mon Jun 26 2017 pgajdos@suse.com
- added
  * mod_proxy-ordering-ProxyPass
  * mod_proxy-ordering-Location
  * mod_proxy-ordering-ProxyPass-Location
  * mod_cgi-stderr
  * mod_cgi-ScriptLog
- mod_reqtimeout-basic now works with 2.2.32
- mod_ssl-basic: allow SSLv3
* Mon May 22 2017 pgajdos@suse.com
- added user(ftp) and group(ftp) to be able to run vsftpd
* Fri Apr 28 2017 pgajdos@suse.com
- added
  * mod_proxy-exceptions
  * mod_sesion-write-read
  * mod_session_crypto-write-read
  * core-FileETag-basic
* Mon Mar 20 2017 pgajdos@suse.com
- do not use %%doc */
* Tue Feb 21 2017 pgajdos@suse.com
- added
  * core-HttpProtocolOptions-basic
- improved several examples along 2.4.25
- turn off debug-coredump as coredumpctl does not report any
  coredumps on change root (see *.spec for details)
* Thu Nov 24 2016 pgajdos@suse.com
- lowered number of expected failures for sle12 and sle12sp1 as we
  link apache2 from :Update now
* Tue Nov 15 2016 pgajdos@suse.com
- added
  * core-chunked-data
  * mod_mime-TypesConfig
* Tue Sep 20 2016 pgajdos@suse.com
- added
  * mod_proxy-cache
  * mod_proxy-cache-poisoning
  * mod_cgi-httpoxy
  * devel-mod_example_1
  * devel-mod_example_2
  * mod_auth_digest-Authorization
  * devel-mod_example_config_simple
  * devel-print-headers
  * devel-read-request-body
  * devel-form-variables
  * mod_filter-AddOutputFilterByType
* Mon Jun  6 2016 pgajdos@suse.com
- added
  * mod_firehose-proxy
  * mod_firehose-connection
  * core-KeepAlive-basic
  * mod_firehose-pipe
  * mod_firehose-demultiplex
  * mod_firehose-basic
  * mod_allowhandlers-basic
  * debug-coredump
  * mod_http2-push
* Tue May 24 2016 pgajdos@suse.com
- added
  * core-Define-basic
  * mod_proxy-long-url-abz53218
  * mod_proxy-long-url-abz53218-waround
* Fri May 20 2016 pgajdos@suse.com
- added
  * mod_lua-LuaMapHandler
  * mod_lua-LuaHookAuthChecker
  * core-ContentDigest-basic
* Wed May 18 2016 pgajdos@suse.com
- added
  * mod_lua-LuaInputFilter
* Tue May 17 2016 pgajdos@suse.com
- added
  * mod_lua-LuaHookFixups
  * mod_lua-LuaOutputFilter
* Mon May 16 2016 pgajdos@suse.com
- added
  * core-IfDefine-basic
  * core-IfModule-basic
* Fri May 13 2016 pgajdos@suse.com
- added
  * core-Warning-basic
  * core-Error-basic
* Thu May 12 2016 pgajdos@suse.com
- AREX_RUN_PORT* variables/expansions renamed to AREX_PORT
* Wed May 11 2016 pgajdos@suse.com
- added mod_lua-LuaHookTypeChecker
* Thu May  5 2016 pgajdos@suse.com
- fixed several examples for httpd 2.5
* Tue May  3 2016 pgajdos@suse.com
- added
  * mod_lua-LuaHookLog
* Thu Apr 28 2016 pgajdos@suse.com
- added
  * core-ServerRoot-basic
* Wed Apr 27 2016 pgajdos@suse.com
- added
  * mod_proxy_scgi-basic
* Tue Apr 26 2016 pgajdos@suse.com
- added
  * mod_lua-LuaHookAccessChecker
* Mon Apr 25 2016 pgajdos@suse.com
- added
  * mod_lua-LuaHookMapToStorage
* Thu Apr 21 2016 pgajdos@suse.com
- added
  * mod_lua-LuaHookTranslateName
  * mod_lua-authz-provider-abz57204
  * mod_lua-hooks
* Wed Apr 20 2016 pgajdos@suse.com
- added
  * mod_lua-LuaQuickHandler
* Tue Apr 19 2016 pgajdos@suse.com
- fixed ServerAdmin-basic for older distros (use cgi script instead
  of document)
* Fri Apr 15 2016 pgajdos@suse.com
- added
  * core-DirectoryMatch-basic
  * core-DirectoryMatch-env
* Thu Apr 14 2016 pgajdos@suse.com
- more git friendly structure: added content-file support,
  dropped numbers from example directories names, added content
  file, dropped insert-new-rex and delete-rex
- added
  * core-ServerAdmin-basic
* Wed Apr 13 2016 pgajdos@suse.com
- added
  * core-ErrorDocument-basic
* Wed Apr 13 2016 pgajdos@suse.com
- fix i586 build
* Tue Apr 12 2016 pgajdos@suse.com
- structure reworked, can be used stand alone
- renamed to apache-rex (Apache HTTPD Runnable Examples)
- insert-new-test renamed to insert-new-rex, delete-test renamed
  to delete-rex, added run-rex, README.md and LICENSE
- spec file reworked accordingly
* Wed Apr  6 2016 pgajdos@suse.com
- added
  * mod_proxy_wstunnel-basic
* Mon Apr  4 2016 pgajdos@suse.com
- added
  * mod_authnz_fcgi-basic
* Fri Apr  1 2016 pgajdos@suse.com
- added
  * mod_proxy_ftp-basic
  * mod_proxy_fcgi-basic
  * mod_proxy_fcgi-php-fpm
* Wed Mar 30 2016 pgajdos@suse.com
- added
  * mod_proxy_connect-basic
* Wed Mar 23 2016 pgajdos@suse.com
- added
  * mod_proxy_express-basic
* Fri Mar 18 2016 pgajdos@suse.com
- added
  * mod_lua-authz-provider
* Thu Mar 17 2016 pgajdos@suse.cz
- added
  * mod_negotiation-basic
  * mod_ratelimit-basic
  * mod_usertrack-basic
* Wed Mar 16 2016 pgajdos@suse.com
- added
  * mod_policy-basic
* Tue Mar 15 2016 pgajdos@suse.com
- added
  * mod_mime_magic-basic
  * mod_lua-basic
* Mon Mar 14 2016 pgajdos@suse.com
- added
  * mod_unique_id-basic
* Wed Mar  9 2016 pgajdos@suse.com
- added
  * mod_cache-filter
  * mod_file_cache-basic
  * mod_expires-basic
* Tue Mar  8 2016 pgajdos@suse.com
- added
  * mod_cache-basic
  * mod_cache-disk
* Fri Mar  4 2016 pgajdos@suse.com
- added
  * mod_session-basic
  * mod_session_crypto-basic
* Thu Mar  3 2016 pgajdos@suse.com
- added
  * mod_data-basic
* Wed Mar  2 2016 pgajdos@suse.com
- added
  * mod_reqtimeout-basic -> buildrequire python for timeout-test.py
- modified
  * mod_dav-basic: for older 2.4 branch it does not return 201,
    not checking it
* Mon Feb 29 2016 pgajdos@suse.com
- added
  * Limit-basic
  * LimitExcept-basic
- modified
  * mod_dav-basic (use RequireAll)
* Fri Feb 26 2016 pgajdos@suse.com
- added
  * mod_dav-basic
* Thu Feb 25 2016 pgajdos@suse.com
- added
  * mod_speling-basic
* Wed Feb 24 2016 pgajdos@suse.com
- added
  * mod_logio-basic
* Tue Feb 23 2016 pgajdos@suse.com
- added
  * mod_macro-basic
* Sun Feb 21 2016 pgajdos@suse.com
- added
  * mod_allowmethods-basic
* Fri Feb 19 2016 pgajdos@suse.com
- added
  * mod_auth_form-basic
* Thu Feb 18 2016 pgajdos@suse.com
- added
  * Satisfy-basic
  * Require-Any-All-None-basic
  * mod_authn_anon-basic
* Wed Feb 17 2016 pgajdos@suse.com
- added
  * mod_authz_groupfile
  * mod_authz_owner
* Fri Feb 12 2016 pgajdos@suse.com
- added
  * mod_authn_dbd-basic
  * mod_authn_dbd-Digest
* Thu Feb 11 2016 pgajdos@suse.com
- added
  * mod_log_debug-basic
* Wed Feb 10 2016 pgajdos@suse.com
- added
  * mod_dumpio-basic
  * LogLevel-basic
* Tue Feb  9 2016 pgajdos@suse.com
- added
  * If-basic
* Mon Feb  8 2016 pgajdos@suse.com
- modified
  * mod_http2-basic: use --http1.1 curl switch instead of relying
    on the default
  * mod_auth_digest-basic: use DefaultRuntimeDir
- added
  * mod_log_forensic-basic
* Sun Feb  7 2016 pgajdos@suse.com
- added
  * mod_auth_digest
* Fri Feb  5 2016 pgajdos@suse.com
- added
  * mod_xml2enc-basic
  * mod_auth_basic-basic
  * mod_authn_dbm-basic
* Thu Feb  4 2016 pgajdos@suse.com
- added
  * mod_headers-basic
  * mod_setenvif-basic
* Wed Feb  3 2016 pgajdos@suse.com
- added
  * mod_rewrite-proxying
  * mod_rewrite-dynamic-vhosts
  * mod_rewrite-advanced
* Tue Feb  2 2016 pgajdos@suse.com
- added
  * mod_rewrite-control-access
  * mod_remoteip-basic
* Mon Feb  1 2016 pgajdos@suse.com
- added
  * ServerAlias-basic
  * mod_vhost_alias-basic
* Fri Jan 29 2016 pgajdos@suse.com
- added
  * UseCanonicalName-basic
* Wed Jan 27 2016 pgajdos@suse.com
- added
  * mod_rewrite-RewriteMap
  * mod_autoindex-basic
* Tue Jan 26 2016 pgajdos@suse.com
- added
  * mod_rewrite-redirecting
  * mod_dir-basic
  * mod_dir-FallbackResource
* Mon Jan 25 2016 pgajdos@suse.com
- added
  * mod_rewrite-RewriteBase
* Thu Jan 21 2016 pgajdos@suse.com
- added
  * mod_rewrite-basic
  * mod_rewrite-RewriteCond
* Wed Jan 20 2016 pgajdos@suse.com
- added
  * mod_access_compat-basic
* Tue Jan 19 2016 pgajdos@suse.com
- added
  * mod_proxy_html-basic
* Mon Jan 18 2016 pgajdos@suse.com
- added
  * mod_ssl-SSLCryptoDevice
* Thu Jan 14 2016 pgajdos@suse.com
- added
  * VirtualHost-name-based
* Thu Jan 14 2016 pgajdos@suse.com
- skip mod_proxy_balancer-failonstatus and mod_proxy_balancer-abz56925
  for version < 2.2.17 inside testsuite, not in spec file
* Mon Jan 11 2016 pgajdos@suse.com
- added
  * mod_http2-basic
* Wed Jan  6 2016 pgajdos@suse.com
- added
  * mod_actions-basic
  * mod_asis-basic
  * mod_version
- fixed
  * mod_filter-basic for 2.2 branch
  * mod_proxy_balancer-basic for 2.4.6
  * mod_proxy_balancer-failonstatus for 2.4.6
  * mod_proxy_balancer-abz56925 for 2.4.6
* Tue Dec 29 2015 pgajdos@suse.com
- added
  * mod_includes-basic
  * mod_mime-filters-chain
* Wed Dec 23 2015 pgajdos@suse.com
- added
  * mod_charset_lite-basic
  * mod_reflector-basic
* Tue Dec 22 2015 pgajdos@suse.com
- added
  * mod_sed-basic
  * mod_mime-filters
  * mod_deflate-basic
* Mon Dec 21 2015 pgajdos@suse.com
- added
  * mod_ssl-basic
  * SetOutputFilter-basic
  * SetInputFilter-basic
* Sat Dec 12 2015 pgajdos@suse.com
- added
  * mod_proxy_balancer-failonstatus
  * mod_proxy_balancer-abz56925
* Fri Dec 11 2015 pgajdos@suse.com
- added:
  * mod_userdir-basic
  * mod_proxy-ProxyErrorOverride
* Thu Dec 10 2015 pgajdos@suse.com
- added:
  * ErrorLogFormat-basic
  * mod_log_config-basic
  * mod_cgi-basic
  * mod_mime-basic
* Wed Dec  9 2015 pgajdos@suse.com
- added:
  * mod_proxy_balancer-basic
  * forward proxy subtest to mod_proxy-basic
  * mod_authz_user-basic
* Tue Dec  8 2015 pgajdos@suse.com
- added:
  * Options-basic
  * AllowOverride-basic
  * mod_proxy-basic
* Mon Dec  7 2015 pgajdos@suse.com
- added:
  * VirtualHost-basic
  * mod_log_config-basic
  * ServerSignature-basic
* Fri Nov 27 2015 pgajdos@suse.com
- added:
  * mod_alias-basic
* Thu Nov 26 2015 pgajdos@suse.com
- added:
  * test-framework
  * mod_auth_core-basic
  * mod_status-basic
  * mod_status-ExtendedStatus-basic
  * mod_info-basic
* Tue Nov 24 2015 pgajdos@suse.com
- package created
